@@ -369,6 +369,14 @@ class EnvironmentInterface(ABC):
             else:
                 all_dependencies_complex.append(Dependency(str(dep)))
 
+        if self.dependency_groups and not self.skip_install:
+            from hatch.utils.dep import get_complex_dependency_group
+
+            for dependency_group in self.dependency_groups:
+                all_dependencies_complex.extend(
+                    get_complex_dependency_group(self.app.project.dependency_groups, dependency_group)
+                )
+
         if self.builder:
             from hatch.project.constants import BuildEnvVars
 
@@ -387,7 +395,7 @@ class EnvironmentInterface(ABC):
 
         # Ensure these are checked last to speed up initial environment creation since
         # they will already be installed along with the project
-        if self.dev_mode:
+        if self.dev_mode or self.features or self.dependency_groups:
             all_dependencies_complex.extend(self.project_dependencies_complex)
 
         return all_dependencies_complex
@@ -407,18 +415,22 @@ class EnvironmentInterface(ABC):
         from hatch.dep.core import Dependency
 
         local_deps = list(self.local_dependencies_complex)
-        other_deps = list(self.dependencies_complex)
-
-        # Create workspace member name set for conflict detection
         workspace_names = {dep.name.lower() for dep in local_deps}
 
-        # Filter out conflicting dependencies, keeping only workspace versions
-        filtered_deps = [
-            dep if isinstance(dep, Dependency) else Dependency(str(dep))
-            for dep in other_deps
-            if dep.name.lower() not in workspace_names
-        ]
-        # Workspace members first to ensure precedence
+        filtered_deps: list[Dependency] = []
+        for dep in self.dependencies_complex:
+            dep_obj = dep if isinstance(dep, Dependency) else Dependency(str(dep))
+
+            if dep_obj.name.lower() in workspace_names and dep_obj.extras:
+                # Only expand if we have static optional dependencies to avoid recursion
+                if not self.metadata.hatch.metadata.hook_config:
+                    optional_dependencies = self.metadata.core.optional_dependencies
+                    for extra in dep_obj.extras:
+                        if extra in optional_dependencies:
+                            filtered_deps.extend(Dependency(d) for d in optional_dependencies[extra])
+            elif dep_obj.name.lower() not in workspace_names:
+                filtered_deps.append(dep_obj)
+
         return local_deps + filtered_deps
 
     @cached_property
@@ -1226,14 +1238,14 @@ class Workspace:
             path_spec = data["path"]
             normalized_path = os.path.normpath(os.path.join(root, path_spec))
             absolute_path = os.path.abspath(normalized_path)
-            shared_prefix = os.path.commonprefix([root, absolute_path])
+            shared_prefix = os.path.commonpath([root, absolute_path])
             relative_path = os.path.relpath(absolute_path, shared_prefix)
 
             # Now we have the necessary information to perform an optimized glob search for members
             members_found = False
-            for member_path in find_members(root, relative_path.split(os.sep)):
+            for member_path in find_members(shared_prefix, relative_path.split(os.sep)):
                 # Check if member should be excluded
-                relative_member_path = os.path.relpath(member_path, root)
+                relative_member_path = os.path.relpath(member_path, shared_prefix)
                 should_exclude = False
                 for exclude_pattern in exclude_patterns:
                     if fnmatch.fnmatch(relative_member_path, exclude_pattern) or fnmatch.fnmatch(
